Decompressor

Trait Decompressor 

pub trait Decompressor:
    Debug
    + Send
    + Sync {
    // Required method
    fn update(
        &mut self,
        data: &[u8],
    ) -> Result<(usize, &[u8]), DecompressionError>;
}

Required Methods

fn update(&mut self, data: &[u8]) -> Result<(usize, &[u8]), DecompressionError>

Tries to decompress data

The return values are the amount of input bytes decompressed, and the result of this decompression operation

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors