Decryptor

Trait Decryptor 

pub trait Decryptor:
    Debug
    + Send
    + Sync {
    // Required method
    fn update(&mut self, data: &[u8]) -> Result<(usize, &[u8]), DecryptionError>;
}

Required Methods

fn update(&mut self, data: &[u8]) -> Result<(usize, &[u8]), DecryptionError>

Tries to decrypt data

The return values are the amount of input bytes consumed, and the result of this decryption operation

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors