LocalFileHeader

Struct LocalFileHeader 

pub struct LocalFileHeader {
    pub version: u16,
    pub flag: u16,
    pub compression_method: Option<CompressionMethod>,
    pub mod_time: u16,
    pub mod_date: u16,
    pub crc32: u32,
    pub compressed_size: u64,
    pub uncompressed_size: u64,
    pub filename: String,
    pub extra_fields: Vec<FileHeaderExtraField>,
    pub encryption: EncryptionData,
    pub header_size: usize,
}
Represents the result of reading a ZIP local file header (LFH)

The layout of this object does not follow the original ZIP LFH structure

Fields

version: u16flag: u16compression_method: Option<CompressionMethod>mod_time: u16mod_date: u16crc32: u32compressed_size: u64uncompressed_size: u64filename: Stringextra_fields: Vec<FileHeaderExtraField>encryption: EncryptionDataheader_size: usize

Implementations

Source

impl LocalFileHeader

pub fn from_bytes(data: impl AsRef<[u8]>) -> Option<Self>

Attempts to read a local file header from the provided byte buffer. Returns None if there isn’t enought data

pub fn is_directory(&self) -> bool

pub fn is_encrypted(&self) -> bool

pub fn create_decryptor( &self, password: &[u8], ) -> Result<Box<dyn Decryptor>, DecryptorCreationError>

Create a Decryptor for the file described by this LFH with the given password. Returns an error if the file is not encrypted.